Learn R Programming

interval (version 1.0-1.2)

summary.icfit: Methods for icfit objects

Description

The print method prints as a list, except the A (clique) matrix. The summary method prints the masses an associated maps for the fit. The [ method allows picking out of specific fits for individual elements of the factor when the right hand side of the formula in icfit was a factor.

Usage

## S3 method for class 'icfit':
summary(object, digits=4,  \dots)

## S3 method for class 'icfit':
print(x, \dots)

## S3 method for class 'icfit':
[(x, i)

Arguments

object
an icfit object
x
an icfit object
digits
number of digits for rounding results
i
scalar integer to pick ith strata
...
arguments to be passed

See Also

ictest

Examples

Run this code
data(bcos)
icout<-icfit(Surv(left,right,type="interval2")~treatment, data=bcos)
print(icout)
summary(icout)
icout[1]

Run the code above in your browser using DataLab