The print method prints as a list, except the A (clique) matrix. The summary method prints the masses an associated maps for the fit. The
[ method allows picking out of specific fits for individual elements of the factor when the right hand side of the formula in icfit
was a factor.
Usage
## S3 method for class 'icfit':
summary(object, digits=4, \dots)
## S3 method for class 'icfit':
print(x, \dots)
## S3 method for class 'icfit':
[(x, i)